==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Senda");
define("_URL","Sl");
define("_PRINTER","Prentvnni sa");
define("_FRIEND","Senda essa frtt til vinar");
define("_YOURNAME","Nafn itt");
define("_OK"," lagi!");
define("_RELATED","Tengt efni");
define("_MOREABOUT","Meira um");
define("_NEWSBY","Frttir fr");
define("_MOSTREAD","Mesta lesna frttin um");
define("_READMORE","Lesa meira...");
define("_BYTESMORE","bti  vibt");
define("_COMMENTSQ","athugasemdir?");
define("_COMMENT","athugasemd");
define("_CONFIGURE","Stillingar");
define("_LOGINCREATE","Innskrning/Skr njan notanda");
define("_THRESHOLD","rskuldur");
define("_NOCOMMENTS","Engar athugasemdir");
define("_NESTED","Inndregin listi");
define("_FLAT","Flatur listi");
define("_THREAD","Spjallrir");
define("_OLDEST","Elsta fyrst");
define("_NEWEST","Njasta fyrst");
define("_HIGHEST","Stigahstu fyrst");
define("_COMMENTSWARNING","Athugasemdirnar eru skoanir vikomandi aila en ekki vefstjra.");
define("_SCORE","Einkunn:");
define("_USERINFO","Notandaupplsingar");
define("_READREST","Lesa afganginn af athugasemdinni...");
define("_REPLY","Svara essu");
define("_REPLYMAIN","Gera athugasemd");
define("_NOSUBJECT","Engin fyrirsgn");
define("_NOANONCOMMENTS","Aeins skrir notendur mega senda inn athugasemdir.   getur <a href=\"modules.php?name=Your_Account\">skr ig hr</a>");
define("_PARENT","Efst  r");
define("_ROOT","Efst");
define("_UCOMMENT","Athugasemd");
define("_ALLOWEDHTML","Leyfilegur HTML ki:");
define("_POSTANON","Senda nafnlaust");
define("_EXTRANS","breytt (HTML tg yfir  texta)");
define("_HTMLFORMATED","HTML sni");
define("_PLAINTEXT","Venjulegur texti");
define("_ONN","um...");
define("_SUBJECT","Efni");
define("_COMMENTREPLY","Skrifa athugasemd");
define("_COMREPLYPRE","Forskoa athugasemd");
define("_NOTRIGHT","Eitthva fr forgrum vi a flytja breytu  etta fall. essi skilabo eru einungis til a rugla ekki hlutum seinna meir");
define("_SENDAMSG","Senda skilabo");
define("_YOUSENDSTORY"," tlar a senda frttina");
define("_TOAFRIEND","til essa vinar ns:");
define("_FYOURNAME","Nafn itt:");
define("_FYOUREMAIL","Netfangi itt:");
define("_FFRIENDNAME","Nafn vinar ns:");
define("_FFRIENDEMAIL","Netfang vinar ns:");
define("_INTERESTING","hugaver frtt ");
define("_HELLO","Sl(l)");
define("_YOURFRIEND","Vinur inn");
define("_CONSIDERED","er  v a eftirfarandi frtt s eitthva fyrir ig og vildi lta ig vita.");
define("_FDATE","Dags:");
define("_FTOPIC","Efnisflokkur:");
define("_YOUCANREAD"," getur lesi fleiri hugaverar frttir ");
define("_FSTORY","Sagan");
define("_HASSENT","Var sent til");
define("_THANKS","Takk fyrir!");
define("_RECOMMEND","Lttu vin inn vita af essari su");
define("_PDATE","Dags:");
define("_PTOPIC","Efnisflokkur:");
define("_COMESFROM","essi grein kemur fr");
define("_THEURL","Vefsl essarar greinar er:");
define("_PREVIEW","Lesa yfir");
define("_NEWUSER","Nr notandi");
define("_OPTIONS","Stillingar");
define("_REFRESH","Endurhlaa");
define("_ADD","Bta vi");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Senda");
define("_URL","Sl");
define("_PRINTER","Prentvnni sa");
define("_FRIEND","Senda essa frtt til vinar");
define("_YOURNAME","Nafn itt");
define("_OK"," lagi!");
define("_RELATED","Tengt efni");
define("_MOREABOUT","Meira um");
define("_NEWSBY","Frttir fr");
define("_MOSTREAD","Mesta lesna frttin um");
define("_READMORE","Lesa meira...");
define("_BYTESMORE","bti  vibt");
define("_COMMENTSQ","athugasemdir?");
define("_COMMENT","athugasemd");
define("_CONFIGURE","Stillingar");
define("_LOGINCREATE","Innskrning/Skr njan notanda");
define("_THRESHOLD","rskuldur");
define("_NOCOMMENTS","Engar athugasemdir");
define("_NESTED","Inndregin listi");
define("_FLAT","Flatur listi");
define("_THREAD","Spjallrir");
define("_OLDEST","Elsta fyrst");
define("_NEWEST","Njasta fyrst");
define("_HIGHEST","Stigahstu fyrst");
define("_COMMENTSWARNING","Athugasemdirnar eru skoanir vikomandi aila en ekki vefstjra.");
define("_SCORE","Einkunn:");
define("_USERINFO","Notandaupplsingar");
define("_READREST","Lesa afganginn af athugasemdinni...");
define("_REPLY","Svara essu");
define("_REPLYMAIN","Gera athugasemd");
define("_NOSUBJECT","Engin fyrirsgn");
define("_NOANONCOMMENTS","Aeins skrir notendur mega senda inn athugasemdir.   getur <a href=\"modules.php?name=Your_Account\">skr ig hr</a>");
define("_PARENT","Efst  r");
define("_ROOT","Efst");
define("_UCOMMENT","Athugasemd");
define("_ALLOWEDHTML","Leyfilegur HTML ki:");
define("_POSTANON","Senda nafnlaust");
define("_EXTRANS","breytt (HTML tg yfir  texta)");
define("_HTMLFORMATED","HTML sni");
define("_PLAINTEXT","Venjulegur texti");
define("_ONN","um...");
define("_SUBJECT","Efni");
define("_COMMENTREPLY","Skrifa athugasemd");
define("_COMREPLYPRE","Forskoa athugasemd");
define("_NOTRIGHT","Eitthva fr forgrum vi a flytja breytu  etta fall. essi skilabo eru einungis til a rugla ekki hlutum seinna meir");
define("_SENDAMSG","Senda skilabo");
define("_YOUSENDSTORY"," tlar a senda frttina");
define("_TOAFRIEND","til essa vinar ns:");
define("_FYOURNAME","Nafn itt:");
define("_FYOUREMAIL","Netfangi itt:");
define("_FFRIENDNAME","Nafn vinar ns:");
define("_FFRIENDEMAIL","Netfang vinar ns:");
define("_INTERESTING","hugaver frtt ");
define("_HELLO","Sl(l)");
define("_YOURFRIEND","Vinur inn");
define("_CONSIDERED","er  v a eftirfarandi frtt s eitthva fyrir ig og vildi lta ig vita.");
define("_FDATE","Dags:");
define("_FTOPIC","Efnisflokkur:");
define("_YOUCANREAD"," getur lesi fleiri hugaverar frttir ");
define("_FSTORY","Sagan");
define("_HASSENT","Var sent til");
define("_THANKS","Takk fyrir!");
define("_RECOMMEND","Lttu vin inn vita af essari su");
define("_PDATE","Dags:");
define("_PTOPIC","Efnisflokkur:");
define("_COMESFROM","essi grein kemur fr");
define("_THEURL","Vefsl essarar greinar er:");
define("_PREVIEW","Lesa yfir");
define("_NEWUSER","Nr notandi");
define("_OPTIONS","Stillingar");
define("_REFRESH","Endurhlaa");
define("_ADD","Bta vi");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
